#
# spec file for package csync
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           csync
Version:        0.50.0
Release:        13.0.2.1.sr20250501
Summary:        A user level bidirectional client only file synchronizer
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
URL:            https://www.csync.org/
Source0:        %{name}-%{version}.tar.bz2
Source1:        baselibs.conf
# PATCH-FIX-OPENSUSE fix-cmake-on-pre-12.patch
Patch0:         fix-cmake-on-pre-12.patch
Patch1:         csync_log.h.patch
# PATCH-FIX-OPENSUSE fix-missing-const.patch
Patch2:         fix-missing-const.patch
# PATCH-FIX-OPENSUSE csync-libssh.patch -- Detect newer libssh versions; hacked patch
Patch3:         csync-libssh.patch
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gcc-c++
BuildRequires:  libsmbclient-devel
BuildRequires:  libssh-devel
BuildRequires:  pkgconfig
%if 0%{?suse_version}
BuildRequires:  sqlite3-devel
%else
BuildRequires:  sqlite-devel
%endif

%description
csync is an implementation of a file synchronizer which provides the
feature of roaming home directories for Linux clients. csync makes use
of libsmbclient in Samba/Windows environments.

%package -n libcsync0
Summary:        A user level bidirectional client only file synchronizer
License:        LGPL-2.1-or-later
Group:          System/Libraries
%if 0%{?suse_version} > 1030
Recommends:     libcsync-plugin-sftp
Recommends:     libcsync-plugin-smb
%endif

%description -n libcsync0
csync is an implementation of a file synchronizer which provides the
feature of roaming home directories for Linux clients. csync makes use
of libsmbclient in Samba/Windows environments.

%package -n libcsync-plugin-smb
Summary:        SMB plugin for csync
License:        GPL-2.0-or-later
Group:          System/Libraries
Requires:       libcsync0 = %{version}

%description -n libcsync-plugin-smb
This plug-in allows applications using csync to synchronize with a
Samba or Windows server.

%package -n libcsync-plugin-sftp
Summary:        A user level bidirectional client only file synchronizer
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
Requires:       libcsync0 = %{version}

%description -n libcsync-plugin-sftp
csync is an implementation of a file synchronizer which provides the
feature of roaming home directories for Linux clients. csync makes use
of libsmbclient in Samba/Windows environments.

%if 0%{?suse_version} >= 1200
%package -n libcsync-plugin-owncloud
Summary:        Owncloud plugin for csync
License:        GPL-2.0-or-later
Group:          System/Libraries
BuildRequires:  libneon-devel
Requires:       libcsync0 = %{version}

%description -n libcsync-plugin-owncloud
This plug-in allows applications using csync to synchronize with Owncloud.
%endif

%package -n libcsync-devel
Summary:        Development files for csync
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       libcsync0 = %{version}

%description -n libcsync-devel
The libcsync-devel package contains the static libraries and header
files needed for development with csync.

%package -n libcsync-devel-doc
Summary:        Developer documentation for csync
License:        GPL-2.0-or-later
Group:          Development/Languages/C and C++

%description -n libcsync-devel-doc
The libcsync-devel-doc package provides documentation for csync
development.

%package -n libcsync-doc
Summary:        User documentation for csync
License:        GPL-2.0-or-later
Group:          Development/Languages/C and C++

%description -n libcsync-doc
The libcsync-doc package provides user documentation for csync.

%prep
%setup -q
%if 0%{?suse_version} < 1200
%patch -P 0 -p1
%endif
%patch -P 1 -p1
%patch -P 2 -p1
if [ -f %{_includedir}/libssh/libssh_version.h ]; then
%patch -P 3 -p1
fi

%build
# Remove cmake4 error due to not setting
# min cmake version - sflees.de
export CMAKE_POLICY_VERSION_MINIMUM=3.5
if test ! -e "build"; then
  mkdir build
fi
pushd build
export LDFLAGS="-pie"
# FIXME: you should use the %%cmake macros
cmake \
  -DCMAKE_C_FLAGS:STRING="%{optflags}" \
  -DCMAKE_CXX_FLAGS:STRING="%{optflags}" \
  -DCMAKE_SKIP_RPATH=ON \
  -DCMAKE_BUILD_TYPE=RelWithDebInfo \
  -DCMAKE_INSTALL_PREFIX=%{_prefix} \
  -DSYSCONF_INSTALL_DIR=%{_sysconfdir} \
%if "%{_lib}" == "lib64"
  -DLIB_SUFFIX=64 \
%endif
  %{_builddir}/%{name}-%{version}
%make_build
%make_build doc
popd

%install
pushd build
%if 0%{?suse_version}
%make_install
%else
%make_install
%endif
popd

%post -n libcsync0 -p /sbin/ldconfig
%postun -n libcsync0 -p /sbin/ldconfig

%files
%{_bindir}/csync
%{_mandir}/man?/csync.*

%files -n libcsync0
%license COPYING
%doc AUTHORS INSTALL README
%dir %{_sysconfdir}/csync
%config(noreplace) %{_sysconfdir}/csync/csync.conf
%config(noreplace) %{_sysconfdir}/csync/csync_exclude.conf
%{_libdir}/libcsync.so.*
%dir %{_libdir}/csync-0

%files -n libcsync-plugin-smb
%{_libdir}/csync-0/csync_smb.so

%files -n libcsync-plugin-sftp
%{_libdir}/csync-0/csync_sftp.so

%if 0%{?suse_version} >= 1200
%files -n libcsync-plugin-owncloud
%{_libdir}/csync-0/csync_owncloud.so
%endif

%files -n libcsync-devel
%{_includedir}/csync
%{_libdir}/libcsync.so

%files -n libcsync-devel-doc
%doc build/doc/html

%files -n libcsync-doc
%{_datadir}/doc/csync

%changelog
* Wed May  7 2025 Simon Lees <sflees@suse.de>
- export CMAKE_POLICY_VERSION_MINIMUM="3.5" to ignore cmakes
  minimum version warnings
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Tue Apr 13 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- explicitly add -pie linker flag to make /usr/bin/csync a PIE binary
  (bsc#1184122). The problem arises in upstream
  cmake/Modules/DefineCompilerFlags.cmake where -fPIC is explicitly added to
  compiler flags, which are also passed during link time. This overrides our
  implicit gcc PIE profile.
* Sun Mar  7 2021 Carsten Ziepke <kieltux@gmail.com>
- Fix bare words are no longer supported,
  please use "...": lib64 == lib64
- Run spec-cleaner
* Tue Oct 27 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Add csync-libssh.patch: Detect libssh version in libssh_version.h
  in case this file exists.
* Tue Oct 30 2018 Klaas Freitag <opensuse@freisturz.de>
- Add fix-missing-const.patch: Fix a compile error on Leap 15.1
  Fixes boo#1113889
* Mon Jun 29 2015 tjcw@physics.org
- Fix build break by changing __FUNCTION__ to __func__
  * csync_log.h.patch
* Mon Mar 16 2015 dimstar@opensuse.org
- Fix popd usage: since bash 4.3, it only takes a numeric argument.
* Mon Jun 30 2014 freitag@owncloud.com
- BuildRequire pkg-config to make cmake find its libraries again.
* Fri Sep 13 2013 jmcdonough@suse.com
- Update to version 0.50.0.
  * Added an owncloud module
  * Added a backup mode to the reconciler
  * Added new logging framework (removed log4c dependency)
  * Added new config parser (removed iniparser dependency)
  * Added capabilities for modules
  * Added content checking in conflict case
  * Improved database performance and integrity checks
  * Improved error reporting
- Add fix-cmake-on-pre-12.patch: Fix building on older systems
* Tue Feb 16 2010 anschneider@exsuse.de
- Build always with libssh support.
* Mon Feb 15 2010 anschneider@exsuse.de
- Update to version 0.44.0.
  * Migrated sftp module to libssh 0.4.
  * Added more cache entries to the default config.
  * Added missing requirements.
  * Fixed build warnings.
  * Fixed some memory leaks using sftp attributes.
  * Some code cleanups.
* Sun Jan 31 2010 jengelh@medozas.de
- Package baselibs.conf
* Mon May 25 2009 anschneider@exsuse.de
- Update to version 0.43.0.
  * Added SFTP support with libssh 0.3.
  * Added possibility to pass userdata to the auth function.
  * Added a better version function.
  * Fixed CMake build.
  * Fixed CMake find modules.
  * Fixed some flaws in cstd functions.
  * Documented all public functions.
* Fri Apr 17 2009 anschneider@exsuse.de
- Fix Fedora build.
- Change the way how to set CFLAGS.
* Thu Feb 26 2009 anschneider@suse.de
- Update to version 0.42.0
  * Small fix in the userguide.
* Fri Jan 23 2009 anschneider@suse.de
- Update to version 0.42.0 rc3
  * Added checks for unix extensions.
  * Added more documentation to the userguide.
  * Fixed loading of plugins.
  * Fixed call for deletion functions.
  * Normalize the path to <hostname>/<path> for the statedb filename.
  * More change name of client options to be more descriptive.
- Add recommends for the plugins.
* Thu Jan  8 2009 anschneider@suse.de
- Fix loading of plugins.
- Add requires to the plugins.
* Thu Jan  8 2009 anschneider@suse.de
- Update to version 0.42.0 rc2
  * Reduced syscalls
  * Fixed a bug in the state database
  * Fixed libsmbclient support
  * Completed userguide
* Fri Dec  5 2008 anschneider@suse.de
- Update to version 0.42.0 rc1
  libcsync:
  * Reduced calls of syscall functions.
  * Added own function to create a temporary filename.
  * Fixed libsmbclient 3.0.x support.
* Wed Sep 10 2008 anschneider@suse.de
- Created a subpackage for each plugin and for the user guide
- Update to version 0.42.0 beta1
  libcsync:
  * Added a sftp module using libssh
  * Added user guide (just a start)
  * Added testcase for update detection
  * Added a function to parse an uri to cstdlib
  * Updated the manpage
  * Fixed some segfaults in cstdlib
  * Fixed some memory leaks
  csync:
  * Improved the auth callback
* Thu Jul  3 2008 anschneider@suse.de
- Set the right group for the different packages
* Wed Jul  2 2008 anschneider@suse.de
- Update to version 0.42.0 alpha4
  libcsync:
  * Added the possibility to run csync completely without a journal
  * Improved chmod calls during propagation. Most of the time we use the
    default mode and don't need to call chmod.
  * Improved the exclude list handling in the file tree walker. This
    increased the speed of the update detection.
  * Fixed csync on PPC
  * Fixed serveral small bugs
  csync:
  * Added commandline option to run csync completely without a journal
* Fri Jun 27 2008 anschneider@suse.de
- Fixed csync on PPC
* Wed Jun 25 2008 anschneider@suse.de
- Update to version 0.42.0 alpha3
  libcsync:
  * Added a tree merger to write a complete journal
  * Added support to run csync without a journal
  * Fixed kerberos support in csync_smb module
  * Fixed closing of files after the copy
  * Fixed update detection to detect special files (fifo, pipes,
    char devices, ..)
  * Fixed O_NOATIME flag on open() if we don't have the permission
  csync:
  * Add a variable to run csync completely without a journal
* Tue Jun 17 2008 anschneider@suse.de
- Fix update detection for special files (fifo, char device, ..)
- Fix propagation for files the user doesn't own
* Mon Jun 16 2008 anschneider@suse.de
- Update to version 0.41.92 (0.42.0 alpha2)
  libcsync:
  * Peformance improvements
  * Add more directories to the standard exclude file
  * Bugfixes
* Wed Jun  4 2008 anschneider@suse.de
- Build for redhat based distributions
* Mon Jun  2 2008 anschneider@suse.de
- Update to version 0.41.91 (0.42.0 alpha1)
* Mon May  5 2008 anschneider@suse.de
- Initial verison 0.41.90
